@@ -18,11 +18,12 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Curses interface class."""
+from __future__ import unicode_literals
 
 import re
 import sys
 
-from glances.compat import u, itervalues
+from glances.compat import to_ascii, nativestr, b, u, itervalues
 from glances.globals import MACOS, WINDOWS
 from glances.logger import logger
 from glances.events import glances_events
@@ -73,6 +74,7 @@ class _GlancesCurses(object):
         'Q': {'switch': 'enable_irq'},
         'R': {'switch': 'disable_raid'},
         's': {'switch': 'disable_sensors'},
+        'S': {'switch': 'sparkline'},
         'T': {'switch': 'network_sum'},
         'U': {'switch': 'network_cumul'},
         'W': {'switch': 'disable_wifi'},
@@ -731,11 +733,11 @@ class _GlancesCurses(object):
         if self.args.disable_left_sidebar:
             return
 
-        for s in self._left_sidebar:
-            if ((hasattr(self.args, 'enable_' + s) or
-                 hasattr(self.args, 'disable_' + s)) and s in stat_display):
+        for p in self._left_sidebar:
+            if ((hasattr(self.args, 'enable_' + p) or
+                 hasattr(self.args, 'disable_' + p)) and p in stat_display):
                 self.new_line()
-                self.display_plugin(stat_display[s])
+                self.display_plugin(stat_display[p])
 
     def __display_right(self, stat_display):
         """Display the right sidebar in the Curses interface.
@@ -752,14 +754,19 @@ class _GlancesCurses(object):
         # Display right sidebar
         self.new_column()
         for p in self._right_sidebar:
-            self.new_line()
-            if p == 'processlist':
-                self.display_plugin(stat_display['processlist'],
-                                    display_optional=(self.screen.getmaxyx()[1] > 102),
-                                    display_additional=(not MACOS),
-                                    max_y=(self.screen.getmaxyx()[0] - self.get_stats_display_height(stat_display['alert']) - 2))
-            else:
-                self.display_plugin(stat_display[p])
+            if ((hasattr(self.args, 'enable_' + p) or
+                 hasattr(self.args, 'disable_' + p)) and p in stat_display):
+                if p not in p:
+                    # Catch for issue #1470
+                    continue
+                self.new_line()
+                if p == 'processlist':
+                    self.display_plugin(stat_display['processlist'],
+                                        display_optional=(self.screen.getmaxyx()[1] > 102),
+                                        display_additional=(not MACOS),
+                                        max_y=(self.screen.getmaxyx()[0] - self.get_stats_display_height(stat_display['alert']) - 2))
+                else:
+                    self.display_plugin(stat_display[p])
 
     def display_popup(self, message,
                       size_x=None, size_y=None,
@@ -1001,20 +1008,18 @@ class _GlancesCurses(object):
         curses.napms(100)
 
     def get_stats_display_width(self, curse_msg, without_option=False):
-        """Return the width of the formatted curses message.
-
-        The height is defined by the maximum line.
-        """
+        """Return the width of the formatted curses message."""
         try:
             if without_option:
                 # Size without options
-                c = len(max(''.join([(re.sub(r'[^\x00-\x7F]+', ' ', i['msg']) if not i['optional'] else "")
+                c = len(max(''.join([(u(u(nativestr(i['msg'])).encode('ascii', 'replace')) if not i['optional'] else "")
                                      for i in curse_msg['msgdict']]).split('\n'), key=len))
             else:
                 # Size with all options
-                c = len(max(''.join([re.sub(r'[^\x00-\x7F]+', ' ', i['msg'])
+                c = len(max(''.join([u(u(nativestr(i['msg'])).encode('ascii', 'replace'))
                                      for i in curse_msg['msgdict']]).split('\n'), key=len))
-        except Exception:
+        except Exception as e:
+            logger.debug('ERROR: Can not compute plugin width ({})'.format(e))
             return 0
         else:
             return c
@@ -1026,7 +1031,8 @@ class _GlancesCurses(object):
         """
         try:
             c = [i['msg'] for i in curse_msg['msgdict']].count('\n')
-        except Exception:
+        except Exception as e:
+            logger.debug('ERROR: Can not compute plugin height ({})'.format(e))
             return 0
         else:
             return c + 1
