@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,8 @@
 
 from datetime import datetime
 
-from glances.logs import glances_logs
+from glances.logger import logger
+from glances.events import glances_events
 from glances.thresholds import glances_thresholds
 # from glances.logger import logger
 from glances.plugins.glances_plugin import GlancesPlugin
@@ -30,6 +31,10 @@ from glances.plugins.glances_plugin import GlancesPlugin
 # - msg: Message to be displayed (result of the decision tree)
 # - threasholds: a list of stats to take into account
 # - thresholds_min: minimal value of the threasholds sum
+# -                 0: OK
+# -                 1: CAREFUL
+# -                 2: WARNING
+# -                 3: CRITICAL
 tree = [{'msg': 'No warning or critical alert detected',
          'thresholds': [],
          'thresholds_min': 0},
@@ -96,8 +101,8 @@ class Plugin(GlancesPlugin):
 
     def update(self):
         """Nothing to do here. Just return the global glances_log."""
-        # Set the stats to the glances_logs
-        self.stats = glances_logs.get()
+        # Set the stats to the glances_events
+        self.stats = glances_events.get()
         # Define the global message thanks to the current thresholds
         # and the decision tree
         # !!! Call directly in the msg_curse function
@@ -109,58 +114,48 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if display plugin enable...
-        if not self.stats and self.is_disable():
+        if not self.stats or self.is_disable():
             return ret
 
         # Build the string message
         # Header
         ret.append(self.curse_add_line(global_message(), "TITLE"))
-        if self.stats:
-            # Header
-            # msg = 'Warning or critical alerts'
-            # ret.append(self.curse_add_line(msg, "TITLE"))
-            # logs_len = glances_logs.len()
-            # if logs_len > 1:
-            #     msg = ' (last {} entries)'.format(logs_len)
-            # else:
-            #     msg = ' (one entry)'
-            # ret.append(self.curse_add_line(msg, "TITLE"))
-            # Loop over alerts
-            for alert in self.stats:
-                # New line
-                ret.append(self.curse_new_line())
-                # Start
-                msg = str(datetime.fromtimestamp(alert[0]))
+        # Loop over alerts
+        for alert in self.stats:
+            # New line
+            ret.append(self.curse_new_line())
+            # Start
+            msg = str(datetime.fromtimestamp(alert[0]))
+            ret.append(self.curse_add_line(msg))
+            # Duration
+            if alert[1] > 0:
+                # If finished display duration
+                msg = ' ({})'.format(datetime.fromtimestamp(alert[1]) -
+                                     datetime.fromtimestamp(alert[0]))
+            else:
+                msg = ' (ongoing)'
+            ret.append(self.curse_add_line(msg))
+            ret.append(self.curse_add_line(" - "))
+            # Infos
+            if alert[1] > 0:
+                # If finished do not display status
+                msg = '{} on {}'.format(alert[2], alert[3])
                 ret.append(self.curse_add_line(msg))
-                # Duration
-                if alert[1] > 0:
-                    # If finished display duration
-                    msg = ' ({})'.format(datetime.fromtimestamp(alert[1]) -
-                                         datetime.fromtimestamp(alert[0]))
-                else:
-                    msg = ' (ongoing)'
+            else:
+                msg = str(alert[3])
+                ret.append(self.curse_add_line(msg, decoration=alert[2]))
+            # Min / Mean / Max
+            if self.approx_equal(alert[6], alert[4], tolerance=0.1):
+                msg = ' ({:.1f})'.format(alert[5])
+            else:
+                msg = ' (Min:{:.1f} Mean:{:.1f} Max:{:.1f})'.format(
+                    alert[6], alert[5], alert[4])
+            ret.append(self.curse_add_line(msg))
+            # Top processes
+            top_process = ', '.join([p['name'] for p in alert[9]])
+            if top_process != '':
+                msg = ': {}'.format(top_process)
                 ret.append(self.curse_add_line(msg))
-                ret.append(self.curse_add_line(" - "))
-                # Infos
-                if alert[1] > 0:
-                    # If finished do not display status
-                    msg = '{} on {}'.format(alert[2], alert[3])
-                    ret.append(self.curse_add_line(msg))
-                else:
-                    msg = str(alert[3])
-                    ret.append(self.curse_add_line(msg, decoration=alert[2]))
-                # Min / Mean / Max
-                if self.approx_equal(alert[6], alert[4], tolerance=0.1):
-                    msg = ' ({:.1f})'.format(alert[5])
-                else:
-                    msg = ' (Min:{:.1f} Mean:{:.1f} Max:{:.1f})'.format(
-                        alert[6], alert[5], alert[4])
-                ret.append(self.curse_add_line(msg))
-                # Top processes
-                top_process = ', '.join([p['name'] for p in alert[9]])
-                if top_process != '':
-                    msg = ': {}'.format(top_process)
-                    ret.append(self.curse_add_line(msg))
 
         return ret
 
