@@ -131,7 +131,8 @@ class Plugin(GlancesPlugin):
             ret.append(self.curse_add_line(msg))
         try:
             msg_pub = '{}'.format(self.stats['public_address'])
-        except UnicodeEncodeError:
+        except (UnicodeEncodeError, KeyError):
+            # Add KeyError exception (see https://github.com/nicolargo/glances/issues/1469)
             pass
         else:
             if self.stats['public_address'] is not None:
@@ -147,7 +148,9 @@ class Plugin(GlancesPlugin):
 
         Example: '255.255.255.0' will return 24
         """
-        return sum([int(x) << 8 for x in ip.split('.')]) // 8128
+        # Thanks to @Atticfire
+        # See https://github.com/nicolargo/glances/issues/1417#issuecomment-469894399
+        return sum(bin(int(x)).count('1') for x in ip.split('.'))
 
 
 class PublicIpAddress(object):
@@ -172,7 +175,7 @@ class PublicIpAddress(object):
             if q.qsize() > 0:
                 ip = q.get()
 
-        return ip
+        return ', '.join(set([x.strip() for x in ip.split(',')]))
 
     def _get_ip_public(self, queue_target, url, json=False, key=None):
         """Request the url service and put the result in the queue_target."""
