@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -28,11 +28,11 @@ import json
 import copy
 from operator import itemgetter
 
-from glances.compat import iterkeys, itervalues, listkeys, map, mean
+from glances.compat import iterkeys, itervalues, listkeys, map, mean, nativestr
 from glances.actions import GlancesActions
 from glances.history import GlancesHistory
 from glances.logger import logger
-from glances.logs import glances_logs
+from glances.events import glances_events
 from glances.thresholds import glances_thresholds
 
 
@@ -149,19 +149,19 @@ class GlancesPlugin(object):
         except UnicodeDecodeError:
             return json.dumps(d, ensure_ascii=False)
 
-    def _history_enable(self):
+    def history_enable(self):
         return self.args is not None and not self.args.disable_history and self.get_items_history_list() is not None
 
     def init_stats_history(self):
         """Init the stats history (dict of GlancesAttribute)."""
-        if self._history_enable():
+        if self.history_enable():
             init_list = [a['name'] for a in self.get_items_history_list()]
             logger.debug("Stats history activated for plugin {} (items: {})".format(self.plugin_name, init_list))
         return GlancesHistory()
 
     def reset_stats_history(self):
         """Reset the stats history (dict of GlancesAttribute)."""
-        if self._history_enable():
+        if self.history_enable():
             reset_list = [a['name'] for a in self.get_items_history_list()]
             logger.debug("Reset history for plugin {} (items: {})".format(self.plugin_name, reset_list))
             self.stats_history.reset()
@@ -174,7 +174,7 @@ class GlancesPlugin(object):
         else:
             item_name = self.get_key()
         # Build the history
-        if self.get_export() and self._history_enable():
+        if self.get_export() and self.history_enable():
             for i in self.get_items_history_list():
                 if isinstance(self.get_export(), list):
                     # Stats is a list of data
@@ -182,14 +182,14 @@ class GlancesPlugin(object):
                     # interface)
                     for l in self.get_export():
                         self.stats_history.add(
-                            str(l[item_name]) + '_' + i['name'],
+                            nativestr(l[item_name]) + '_' + nativestr(i['name']),
                             l[i['name']],
                             description=i['description'],
                             history_max_size=self._limits['history_size'])
                 else:
                     # Stats is not a list
                     # Add the item to the history directly
-                    self.stats_history.add(i['name'],
+                    self.stats_history.add(nativestr(i['name']),
                                            self.get_export()[i['name']],
                                            description=i['description'],
                                            history_max_size=self._limits['history_size'])
@@ -390,7 +390,8 @@ class GlancesPlugin(object):
             try:
                 # Source:
                 # http://stackoverflow.com/questions/4573875/python-get-index-of-dictionary-item-in-list
-                return self._json_dumps({item: map(itemgetter(item), self.stats)})
+                # But https://github.com/nicolargo/glances/issues/1401
+                return self._json_dumps({item: list(map(itemgetter(item), self.stats))})
             except (KeyError, ValueError) as e:
                 logger.error("Cannot get item {} ({})".format(item, e))
                 return None
@@ -530,6 +531,13 @@ class GlancesPlugin(object):
         """
         return self.stats
 
+    def get_stat_name(self, header=""):
+        """"Return the stat name with an optional header"""
+        ret = self.plugin_name
+        if header != "":
+            ret += '_' + header
+        return ret
+
     def get_alert(self,
                   current=0,
                   minimum=0,
@@ -572,11 +580,8 @@ class GlancesPlugin(object):
         except TypeError:
             return 'DEFAULT'
 
-        # Build the stat_name = plugin_name + header
-        if header == "":
-            stat_name = self.plugin_name
-        else:
-            stat_name = self.plugin_name + '_' + header
+        # Build the stat_name
+        stat_name = self.get_stat_name(header=header)
 
         # Manage limits
         # If is_max is set then display the value in MAX
@@ -600,7 +605,7 @@ class GlancesPlugin(object):
             # So stats will be highlited with a specific color
             log_str = "_LOG"
             # Add the log to the list
-            glances_logs.add(ret, stat_name.upper(), value)
+            glances_events.add(ret, stat_name.upper(), value)
 
         # Manage threshold
         self.manage_threshold(stat_name, ret)
@@ -616,7 +621,6 @@ class GlancesPlugin(object):
                          trigger):
         """Manage the threshold for the current stat."""
         glances_thresholds.add(stat_name, trigger)
-        # logger.info(glances_thresholds.get())
 
     def manage_action(self,
                       stat_name,
@@ -681,7 +685,7 @@ class GlancesPlugin(object):
 
         # logger.debug("{} {} value is {}".format(stat_name, criticity, limit))
 
-        # Return the limit
+        # Return the limiter
         return limit
 
     def get_limit_action(self, criticity, stat_name=""):
