@@ -22,6 +22,7 @@
 from glances.cpu_percent import cpu_percent
 from glances.logger import logger
 from glances.outputs.glances_bars import Bar
+from glances.outputs.glances_sparklines import Sparkline
 from glances.plugins.glances_plugin import GlancesPlugin
 
 import psutil
@@ -36,6 +37,22 @@ else:
     cpuinfo_tag = True
 
 
+# Define the history items list
+# All items in this list will be historised if the --enable-history tag is set
+items_history_list = [{'name': 'cpu',
+                       'description': 'CPU percent usage',
+                       'y_unit': '%'},
+                      {'name': 'percpu',
+                       'description': 'PERCPU percent usage',
+                       'y_unit': '%'},
+                      {'name': 'mem',
+                       'description': 'MEM percent usage',
+                       'y_unit': '%'},
+                      {'name': 'swap',
+                       'description': 'SWAP percent usage',
+                       'y_unit': '%'}]
+
+
 class Plugin(GlancesPlugin):
     """Glances quicklook plugin.
 
@@ -44,8 +61,8 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None):
         """Init the quicklook plugin."""
-        super(Plugin, self).__init__(args=args)
-
+        super(Plugin, self).__init__(args=args,
+                                     items_history_list=items_history_list)
         # We want to display the stat in the curse interface
         self.display_curse = True
 
@@ -105,8 +122,14 @@ class Plugin(GlancesPlugin):
         if not self.stats or self.is_disable():
             return ret
 
-        # Define the bar
-        bar = Bar(max_width)
+        # Define the data: Bar (default behavor) or Sparkline
+        sparkline_tag = False
+        if self.args.sparkline and self.history_enable():
+            data = Sparkline(max_width)
+            sparkline_tag = data.available
+        if not sparkline_tag:
+            # Fallback to bar if Sparkline module is not installed
+            data = Bar(max_width)
 
         # Build the string message
         if 'cpu_name' in self.stats and 'cpu_hz_current' in self.stats and 'cpu_hz' in self.stats:
@@ -119,18 +142,34 @@ class Plugin(GlancesPlugin):
             ret.append(self.curse_new_line())
         for key in ['cpu', 'mem', 'swap']:
             if key == 'cpu' and args.percpu:
-                for cpu in self.stats['percpu']:
-                    bar.percent = cpu['total']
+                if sparkline_tag:
+                    raw_cpu = self.get_raw_history(item='percpu', nb=data.size)
+                for cpu_index, cpu in enumerate(self.stats['percpu']):
+                    if sparkline_tag:
+                        # Sparkline display an history
+                        data.percents = [i[1][cpu_index]['total'] for i in raw_cpu]
+                        # A simple padding in order to align metrics to the right
+                        data.percents += [None] * (data.size - len(data.percents))
+                    else:
+                        # Bar only the last value
+                        data.percent = cpu['total']
                     if cpu[cpu['key']] < 10:
                         msg = '{:3}{} '.format(key.upper(), cpu['cpu_number'])
                     else:
                         msg = '{:4} '.format(cpu['cpu_number'])
-                    ret.extend(self._msg_create_line(msg, bar, key))
+                    ret.extend(self._msg_create_line(msg, data, key))
                     ret.append(self.curse_new_line())
             else:
-                bar.percent = self.stats[key]
+                if sparkline_tag:
+                    # Sparkline display an history
+                    data.percents = [i[1] for i in self.get_raw_history(item=key, nb=data.size)]
+                    # A simple padding in order to align metrics to the right
+                    data.percents += [None] * (data.size - len(data.percents))
+                else:
+                    # Bar only the last value
+                    data.percent = self.stats[key]
                 msg = '{:4} '.format(key.upper())
-                ret.extend(self._msg_create_line(msg, bar, key))
+                ret.extend(self._msg_create_line(msg, data, key))
                 ret.append(self.curse_new_line())
 
         # Remove the last new line
@@ -139,14 +178,14 @@ class Plugin(GlancesPlugin):
         # Return the message with decoration
         return ret
 
-    def _msg_create_line(self, msg, bar, key):
+    def _msg_create_line(self, msg, data, key):
         """Create a new line to the Quickview."""
         ret = []
 
         ret.append(self.curse_add_line(msg))
-        ret.append(self.curse_add_line(bar.pre_char, decoration='BOLD'))
-        ret.append(self.curse_add_line(str(bar), self.get_views(key=key, option='decoration')))
-        ret.append(self.curse_add_line(bar.post_char, decoration='BOLD'))
+        ret.append(self.curse_add_line(data.pre_char, decoration='BOLD'))
+        ret.append(self.curse_add_line(data.get(), self.get_views(key=key, option='decoration')))
+        ret.append(self.curse_add_line(data.post_char, decoration='BOLD'))
         ret.append(self.curse_add_line('  '))
 
         return ret
